@@ -1,4 +1,4 @@
-/* Copyright © 2007-2014 Jakub Wilk
+/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This package is free software; you can redistribute it and/or modify
@@ -86,7 +86,7 @@ class FgColorsOutsideRange : public Config::Error
 {
 public:
   FgColorsOutsideRange(unsigned int n, unsigned int m)
-  : Error(string_printf(_("The specified number of foreground colors is outside the allowed range: %u .. %u"), n, m))
+  : Config::Error(string_printf(_("The specified number of foreground colors is outside the allowed range: %u .. %u"), n, m))
   { }
 };
 
@@ -94,7 +94,23 @@ class SubsampleRatioOutsideRange : public Config::Error
 {
 public:
   SubsampleRatioOutsideRange(unsigned int n, unsigned int m)
-  : Error(string_printf(_("The specified subsampling ratio is outside the allowed range: %u .. %u"), n, m))
+  : Config::Error(string_printf(_("The specified subsampling ratio is outside the allowed range: %u .. %u"), n, m))
+  { }
+};
+
+class LossLevelWithoutMonochrome : public Config::Error
+{
+public:
+  LossLevelWithoutMonochrome()
+  : Config::Error(_("--loss-level requires enabling --monochrome"))
+  { }
+};
+
+class InputOutputClash : public Config::Error
+{
+public:
+  explicit InputOutputClash(const std::string &path)
+  : Config::Error(string_printf(_("Input file is the same as output file: %s"), path.c_str()))
   { }
 };
 
@@ -446,8 +462,8 @@ void Config::read_config(int argc, char * const argv[])
     { "indirect", 1, 0, OPT_INDIRECT },
     { "jobs", 1, 0, OPT_JOBS },
     { "lines", 0, 0, OPT_TEXT_LINES },
-    { "loss-level", 1, 0, OPT_LOSS_ANY }, /* deprecated alias */
-    { "losslevel", 1, 0, OPT_LOSS_ANY },
+    { "loss-level", 1, 0, OPT_LOSS_ANY },
+    { "losslevel", 1, 0, OPT_LOSS_ANY }, /* deprecated alias */
     { "lossy", 0, 0, OPT_LOSS_100 },
     { "media-box", 0, 0, OPT_MEDIA_BOX },
     { "monochrome", 0, 0, OPT_MONOCHROME },
@@ -633,12 +649,16 @@ void Config::read_config(int argc, char * const argv[])
       throw std::logic_error(_("Unknown option"));
     }
   }
+  if (this->loss_level > 0 && !this->monochrome)
+    throw LossLevelWithoutMonochrome();
   if (optind > argc - 1)
     throw NoInputFile();
   else
     while (optind < argc)
     {
       this->filenames.push_back(argv[optind]);
+      if (is_same_file(this->output, argv[optind]))
+        throw InputOutputClash(this->output);
       optind++;
     }
 }
