@@ -1,4 +1,4 @@
-/* Copyright © 2007-2015 Jakub Wilk
+/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This package is free software; you can redistribute it and/or modify
@@ -20,18 +20,11 @@
 #include "debug.hh"
 #include "i18n.hh"
 #include "pdf-backend.hh"
+#include "pdf-unicode.hh"
 #include "system.hh"
 
 #include <Error.h>
 #include <GlobalParams.h>
-#include <PDFDocEncoding.h>
-#if (POPPLER_VERSION < 2100) || (POPPLER_VERSION >= 2101)
-#include <UTF8.h>
-#endif
-#if POPPLER_VERSION >= 2100
-#include <UTF.h>
-#endif
-#include <UnicodeTypeTable.h>
 
 /* class pdf::Environment
  * ======================
@@ -324,16 +317,16 @@ std::string pdf::Timestamp::format(char separator) const
   format[8] = separator;
   struct tm tmp_timestamp = this->timestamp;
   if (mktime(&tmp_timestamp) == static_cast<time_t>(-1))
-    throw Invalid();
+    throw pdf::Timestamp::Invalid();
   if (strftime(buffer, sizeof buffer, format, &this->timestamp) != 19)
-    throw Invalid();
+    throw pdf::Timestamp::Invalid();
   stream << buffer;
   if (this->tz_sign)
   {
     if (this->tz_hour < 0 || this->tz_hour >= 24)
-      throw Invalid();
+      throw pdf::Timestamp::Invalid();
     if (this->tz_minute < 0 || this->tz_minute >= 60)
-      throw Invalid();
+      throw pdf::Timestamp::Invalid();
     stream
       << this->tz_sign
       << std::setw(2) << std::setfill('0') << this->tz_hour
@@ -581,106 +574,6 @@ pdf::Object *pdf::dict_lookup(pdf::Dict *dict, const char *key, pdf::Object *obj
 }
 
 
-/* Unicode → UTF-8 conversion
- * ==========================
- */
-
-void pdf::write_as_utf8(std::ostream &stream, Unicode unicode_char)
-{
-  char buffer[8];
-  int seqlen = mapUTF8(unicode_char, buffer, sizeof buffer);
-  stream.write(buffer, seqlen);
-}
-
-std::string pdf::string_as_utf8(pdf::String *string)
-{
-  /* See
-   * http://unicode.org/faq/utf_bom.html
-   * for description of both UTF-16 and UTF-8.
-   */
-  const static uint32_t replacement_character = 0xfffd;
-  const char *cstring = string->getCString();
-  size_t clength = string->getLength();
-  std::ostringstream stream;
-  if (clength >= 2 && (cstring[0] & 0xff) == 0xfe && (cstring[1] & 0xff) == 0xff)
-  {
-    /* UTF-16-BE Byte Order Mark has been recognized. */
-    uint32_t code, code_shift = 0;
-    for (size_t i = 2; i < clength; i += 2)
-    {
-      if (i + 1 < clength)
-        code = ((cstring[i] & 0xff) << 8) + (cstring[i + 1] & 0xff);
-      else
-      {
-        /* A lone byte is encountered. */
-        code = replacement_character;
-      }
-      if (code_shift)
-      {
-        /* A leading surrogate has been encountered. */
-        if (code >= 0xdc00 && code < 0xe000)
-        {
-          /* A trailing surrogate is encountered. */
-          code = code_shift + (code & 0x3ff);
-          if (code >= 0x110000)
-            code = replacement_character;
-        }
-        else
-        {
-          /* An unpaired surrogate is encountered. */
-          code = replacement_character;
-        }
-        code_shift = 0;
-      }
-      else if (code >= 0xd800 && code < 0xdc00)
-      {
-        /* A leading surrogate is encountered. */
-        code_shift = 0x10000 + ((code & 0x3ff) << 10);
-        continue;
-      }
-      if ((code & 0xfffe) == 0xfffe)
-      {
-        /* A non-character is encountered. */
-        code = replacement_character;
-      }
-      if (code < 0x80)
-      {
-        char ascii = code;
-        stream << ascii;
-      }
-      else
-      {
-        char buffer[4];
-        size_t nbytes;
-        for (nbytes = 2; nbytes < 4; nbytes++)
-          if (code < (1U << (5 * nbytes + 1)))
-            break;
-        buffer[0] = (0xff00 >> nbytes) & 0xff;
-        for (size_t i = nbytes - 1; i; i--)
-        {
-          buffer[i] = 0x80 | (code & 0x3f);
-          code >>= 6;
-        }
-        buffer[0] |= code;
-        stream.write(buffer, nbytes);
-      }
-    }
-  }
-  else
-  {
-    /* Use the PDFDoc encoding. */
-    for (size_t i = 0; i < clength; i++)
-      write_as_utf8(stream, pdfDocEncoding[cstring[i] & 0xff]);
-  }
-  return stream.str();
-}
-
-std::string pdf::string_as_utf8(pdf::Object &object)
-{
-  return pdf::string_as_utf8(object.getString());
-}
-
-
 /* class pdf::Pixmap
  * =================
  */
@@ -711,27 +604,4 @@ namespace pdf
   }
 }
 
-
-/* class pdf::NFKC
- * ===============
- */
-
-pdf::NFKC::NFKC(Unicode *unistr, int length)
-: data(NULL), int_length(0)
-{
-  data = unicodeNormalizeNFKC(unistr, length, &this->int_length, NULL);
-}
-
-pdf::NFKC::~NFKC() throw ()
-{
-  gfree(this->data);
-}
-
-#if POPPLER_VERSION >= 1900
-/* Preempt this poppler function, so that it doesn't stand in our way. */
-pdf::Bool unicodeIsAlphabeticPresentationForm(Unicode c) {
-  return 0;
-}
-#endif
-
 // vim:ts=2 sts=2 sw=2 et
