@@ -1,4 +1,4 @@
-/* Copyright © 2007-2015 Jakub Wilk
+/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This package is free software; you can redistribute it and/or modify
@@ -32,6 +32,7 @@
 #include "paths.hh"
 #include "pdf-backend.hh"
 #include "pdf-dpi.hh"
+#include "pdf-unicode.hh"
 #include "sexpr.hh"
 #include "system.hh"
 #include "xmp.hh"
@@ -434,15 +435,10 @@ public:
         return;
     }
     std::auto_ptr<pdf::NFKC> nfkc;
-    const Unicode *const_unistr;
     if (config.text_nfkc)
-    {
-      nfkc.reset(new pdf::NFKC(unistr, length));
-      const_unistr = *nfkc;
-      length = nfkc->length();
-    }
+      nfkc.reset(new pdf::FullNFKC(unistr, length));
     else
-      const_unistr = unistr;
+      nfkc.reset(new pdf::MinimalNFKC(unistr, length));
     add_text_comment(
       static_cast<int>(pox),
       static_cast<int>(poy),
@@ -452,7 +448,7 @@ public:
       static_cast<int>(py),
       static_cast<int>(pw),
       static_cast<int>(ph),
-      const_unistr, length
+      *nfkc, nfkc->length()
     );
   }
 
@@ -824,6 +820,14 @@ std::string DjVuCommand::dir_name(program_dir);
 std::string DjVuCommand::dir_name(paths::djvulibre_bindir);
 #endif
 
+class DuplicatePage : public std::runtime_error
+{
+public:
+  DuplicatePage(int n)
+  : std::runtime_error(string_printf(_("Duplicate page: %d"), n))
+  { }
+};
+
 class DjVm
 {
 protected:
@@ -1174,7 +1178,7 @@ static void calculate_subsampled_size(int width, int height, int ratio, int &sub
   /* DjVuLibre expects that:
    *
    *   sub_width = ceil(width / ratio)
-   *   sub_width = ceil(height / ratio)
+   *   sub_height = ceil(height / ratio)
    *
    * However, DjVu Reference (10.3) requires that:
    *
@@ -1207,7 +1211,12 @@ static int xmain(int argc, char * const argv[])
   catch (const Config::NeedVersion)
   {
     error_log << get_multiline_version();
-    exit(1);
+    exit(0);
+  }
+  catch (const Config::NeedHelp &ex)
+  {
+    config.usage(ex);
+    exit(0);
   }
   catch (const Config::Error &ex)
   {
@@ -1329,8 +1338,11 @@ static int xmain(int argc, char * const argv[])
   for (int n = page_range->first; n <= n_pages && n <= page_range->second; n++)
   {
     static int i = 1;
+    if (page_map.get(n, 0))
+      throw DuplicatePage(n);
     page_map.set(n, i);
     page_numbers.push_back(n);
+    *djvm << (*page_files)[n];
     i++;
   }
 
@@ -1611,12 +1623,6 @@ static int xmain(int argc, char * const argv[])
     error_log << ex << std::endl;
     exit(1);
   }
-  /* Separate loop to avoid parallelization: */
-  for (size_t i = 0; i < page_numbers.size(); i++)
-  {
-    int n = page_numbers[i];
-    *djvm << (*page_files)[n];
-  }
   /* Only first PDF document metadata/outline is taken into account. */
   doc.reset(new pdf::Document(config.filenames[0]));
   if (config.extract_metadata)
