@@ -1,4 +1,4 @@
-/* Copyright © 2007-2015 Jakub Wilk
+/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This package is free software; you can redistribute it and/or modify
@@ -10,18 +10,18 @@
 #include <cerrno>
 #include <cstdarg>
 #include <cstdlib>
-#include <cstdarg>
 #include <cstring>
 #include <limits>
 #include <sstream>
 #include <stdexcept>
 
-#include <fcntl.h>
 #include <dirent.h>
+#include <fcntl.h>
 #include <libgen.h>
 #include <stdint.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <unistd.h>
 
 #if WIN32
 #include <climits>
@@ -324,7 +324,7 @@ static const std::string argv_to_command_line(const std::vector<std::string> &ar
    *    number of backslashes is odd, the last backslash escapes the next
    *    double quotation mark as described in rule 3.
    *
-   * See <http://msdn.microsoft.com/en-us/library/ms880421.aspx>.
+   * See <https://msdn.microsoft.com/en-us/library/ms880421.aspx>.
    */
   for (std::vector<std::string>::const_iterator parg = argv.begin(); parg != argv.end(); parg++)
   {
@@ -847,6 +847,7 @@ std::string Command::filter(const std::string &command_line, const std::string s
   /* Should not really happen. */
   errno = ENOSYS;
   throw_posix_error("fork");
+  return "";
 }
 
 #endif
@@ -1055,10 +1056,6 @@ void TemporaryFile::construct()
     throw_win32_error("GetTempPath");
   if (GetTempFileName(base_path_buffer, PACKAGE_NAME, 0, path_buffer) == 0)
     throw_win32_error("GetTempFileName");
-  HANDLE handle = CreateFile(path_buffer, 0, 0, NULL, CREATE_NEW, FILE_ATTRIBUTE_TEMPORARY, NULL);
-  if (handle == 0)
-    throw_win32_error("CreateFile");
-  CloseHandle(handle); /* ignore errors */
 #endif
   this->open(path_buffer);
 }
@@ -1235,15 +1232,14 @@ namespace encoding
       code = wstring[i];
       if (code_shift)
       {
-        /* A leading surrogate has been encountered. */
         if (code >= 0xdc00 && code < 0xe000)
         {
-          /* A trailing surrogate is encountered. */
+          /* trailing surrogate */
           code = code_shift + (code & 0x3ff);
         }
         else
         {
-          /* An unpaired surrogate is encountered. */
+          /* unpaired surrogate */
           errno = EILSEQ;
           throw_posix_error(__FUNCTION__);
         }
@@ -1251,13 +1247,13 @@ namespace encoding
       }
       else if (code >= 0xd800 && code < 0xdc00)
       {
-        /* A leading surrogate is encountered. */
+        /* leading surrogate */
         code_shift = 0x10000 + ((code & 0x3ff) << 10);
         continue;
       }
       if (code >= 0x110000 || (code & 0xfffe) == 0xfffe)
       {
-        /* Code is out of range or a non-character is encountered. */
+        /* code is out of range or a non-character */
         errno = EILSEQ;
         throw_posix_error(__FUNCTION__);
       }
@@ -1441,6 +1437,45 @@ std::string absolute_path(const std::string &path, const std::string &dir_name)
   return path;
 }
 
+bool is_same_file(const std::string &path1, const std::string &path2)
+{
+#if WIN32
+  BY_HANDLE_FILE_INFORMATION info1, info2;
+  HANDLE handle;
+  int ok;
+  handle = CreateFile(path1.c_str(), FILE_READ_ATTRIBUTES, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
+  if (handle == INVALID_HANDLE_VALUE)
+    return false;
+  ok = GetFileInformationByHandle(handle, &info1);
+  CloseHandle(handle);
+  if (!ok)
+    return false;
+  handle = CreateFile(path2.c_str(), FILE_READ_ATTRIBUTES, FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
+  if (handle == INVALID_HANDLE_VALUE)
+    return false;
+  ok = GetFileInformationByHandle(handle, &info2);
+  CloseHandle(handle);
+  if (!ok)
+    return false;
+  return
+    (info1.dwVolumeSerialNumber == info2.dwVolumeSerialNumber) &&
+    (info1.nFileSizeLow == info2.nFileSizeLow) &&
+    (info1.nFileSizeHigh == info2.nFileSizeHigh);
+#else
+  struct stat st1, st2;
+  int rc;
+  rc = stat(path1.c_str(), &st1);
+  if (rc)
+    return false;
+  rc = stat(path2.c_str(), &st2);
+  if (rc)
+    return false;
+  return
+    (st1.st_dev == st2.st_dev) &&
+    (st1.st_ino == st2.st_ino);
+#endif
+}
+
 #if defined(va_copy)
 #elif defined(__va_copy)
 #define va_copy __va_copy
@@ -1454,12 +1489,15 @@ std::string string_vprintf(const char *message, va_list args)
   va_copy(args_copy, args);
   int length = vsnprintf(NULL, 0, message, args_copy);
   va_end(args_copy);
-  assert(length >= 0);
   if (length < 0)
     throw_posix_error("vsnprintf");
+  if (length == std::numeric_limits<int>::max())
+  {
+    errno = ENOMEM;
+    throw_posix_error("vsnprintf");
+  }
   Array<char> buffer(length + 1);
   length = vsprintf(buffer, message, args);
-  assert(length >= 0);
   if (length < 0)
     throw_posix_error("vsprintf");
   return static_cast<char*>(buffer);
