@@ -1,7 +1,6 @@
-#!/usr/bin/python
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,9 +19,9 @@ re.type = type(re(''))
 from nose import SkipTest
 
 from nose.tools import (
-    assert_true,
     assert_equal,
     assert_not_equal,
+    assert_true,
 )
 
 try:
@@ -43,13 +42,13 @@ except ImportError:
             return
         if msg is None:
             msg = "Regexp didn't match"
-        msg = '%s: %r not found in %r' % (msg, expected_regexp.pattern, text)
+        msg = '{msg}: {re!r} not found in {text!r}'.format(msg=msg, re=expected_regexp.pattern, text=text)
         raise AssertionError(msg)
 
 def assert_well_formed_xml(xml):
     try:
         etree.fromstring(xml)
-    except SyntaxError, ex:
+    except SyntaxError as ex:
         raise AssertionError(ex)
 
 class ipc_result(object):
@@ -80,20 +79,20 @@ class case(object):
     _pdf2djvu_command = os.getenv('pdf2djvu') or 'pdf2djvu'
 
     def get_pdf2djvu_command(self):
-        return self._pdf2djvu_command
+        return ('sh', '-c', self._pdf2djvu_command + ' "$@"', 'sh')
 
-    def get_source_file(self, strip_py=False):
+    def get_source_path(self, strip_py=False):
         result = inspect.getsourcefile(type(self))
         if strip_py and result.endswith('.py'):
             return result[:-3]
         else:
             return result
 
-    def get_pdf_file(self):
-        return self.get_source_file(strip_py=True) + '.pdf'
+    def get_pdf_path(self):
+        return self.get_source_path(strip_py=True) + '.pdf'
 
-    def get_djvu_file(self):
-        return self.get_source_file(strip_py=True) + '.djvu'
+    def get_djvu_path(self):
+        return self.get_source_path(strip_py=True) + '.djvu'
 
     def run(self, *commandline):
         env = dict(os.environ,
@@ -106,41 +105,37 @@ class case(object):
             env=env,
         )
         stdout, stderr = child.communicate()
-        stderr = re('^(?:  \S+ --> \S+ \(\d+ bytes\)\n)+$').sub('', stderr) # strip djvuextract cruft
+        stderr = re('^(?:  \S+ --> \S+ \(\d+ bytes\)\n)+$').sub('', stderr)  # strip djvuextract cruft
         return ipc_result(stdout, stderr, child.returncode)
 
     def _pdf2djvu(self, *args):
-        return self.run(
-            self.get_pdf2djvu_command(),
-            '-q',
-            self.get_pdf_file(),
-            *args
-        )
+        args = self.get_pdf2djvu_command() + ('-q', self.get_pdf_path()) + args
+        return self.run(*args)
 
     def pdf2djvu(self, *args):
-        return self._pdf2djvu('-o', self.get_djvu_file(), *args)
+        return self._pdf2djvu('-o', self.get_djvu_path(), *args)
 
     def pdf2djvu_indirect(self, *args):
-        return self._pdf2djvu('-i', self.get_djvu_file(), *args)
+        return self._pdf2djvu('-i', self.get_djvu_path(), *args)
 
     def djvudump(self, *args):
-        return self.run('djvudump', self.get_djvu_file(), *args)
+        return self.run('djvudump', self.get_djvu_path(), *args)
 
     def djvused(self, expr):
         return self.run(
             'djvused',
             '-e', expr,
-            self.get_djvu_file()
+            self.get_djvu_path()
         )
 
     def print_text(self):
-        return self.run('djvutxt', self.get_djvu_file())
+        return self.run('djvutxt', self.get_djvu_path())
 
     def print_outline(self):
         return self.djvused('print-outline')
 
     def print_ant(self, page):
-        return self.djvused('select %d; print-ant' % page)
+        return self.djvused('select {0}; print-ant'.format(page))
 
     def print_meta(self):
         return self.djvused('print-meta')
@@ -148,7 +143,7 @@ class case(object):
     def decode(self):
         return self.run(
             'ddjvu',
-            self.get_djvu_file()
+            self.get_djvu_path()
         )
 
     def extract_xmp(self):
@@ -166,7 +161,7 @@ class case(object):
 
     def require_feature(self, feature):
         r = self.pdf2djvu('--version')
-        r.assert_(stderr=re('^pdf2djvu '), rc=1)
+        r.assert_(stderr=re('^pdf2djvu '), rc=0)
         if feature not in r.stderr:
             raise SkipTest(feature + ' support missing')
 
@@ -179,7 +174,7 @@ def rainbow(width, height):
         for y in xrange(height):
             hue = 255 * x // (width - 1)
             luminance = 100 * y // height
-            color = ImageColor.getrgb('hsl(%(hue)d, 100%%, %(luminance)d%%)' % locals())
+            color = ImageColor.getrgb('hsl({hue}, 100%, {lum}%)'.format(hue=hue, lum=luminance))
             pixels[x, y] = color
     return image
 
