@@ -1,13 +1,13 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2014 Jakub Wilk
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; version 2 dated June, 1991.
 
 from common import (
-    case
+    case,
 )
 
 class test(case):
