@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010-2015 Jakub Wilk
+# Copyright © 2010-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ class test(case):
 
     def _test(self, i):
         self.require_feature('GraphicsMagick')
-        self.pdf2djvu('--fg-colors=%d' % i).assert_()
+        self.pdf2djvu('--fg-colors={0}'.format(i)).assert_()
         r = self.decode()
         r.assert_(stdout=None)
 
