@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2010-2014 Jakub Wilk
+# Copyright © 2010-2014 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ class test(case):
             yield self._test, method
 
     def _test(self, method):
-        self.pdf2djvu('--fg-colors=%s' % method).assert_()
+        self.pdf2djvu('--fg-colors={method}'.format(method=method)).assert_()
         r = self.decode()
         r.assert_(stdout=None)
 
