@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2009-2015 Jakub Wilk
+# Copyright © 2009-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # This package is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,19 +17,18 @@ class test(case):
     '''
     fixed in [18b2ae04de2f], [fa7d4addf18e]
     '''
-
-    text = u'\N{LATIN SMALL LIGATURE FL}uorogra\N{LATIN SMALL LIGATURE FI}a'
+    text = u'bar\N{LATIN SMALL LETTER DZ}o'
     text_nfkc = unicodedata.normalize('NFKC', text).encode('UTF-8')
     text_no_nfkc = text.encode('UTF-8')
 
     def test_nfkc(self):
         self.pdf2djvu().assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^%s *$' % self.text_nfkc, re.M))
+        r.assert_(stdout=re('^{s} *$'.format(s=self.text_nfkc), re.M))
 
     def test_no_nfkc(self):
         self.pdf2djvu('--no-nfkc').assert_()
         r = self.print_text()
-        r.assert_(stdout=re('^%s *$' % self.text_no_nfkc, re.M))
+        r.assert_(stdout=re('^{s} *$'.format(s=self.text_no_nfkc), re.M))
 
 # vim:ts=4 sts=4 sw=4 et
